"""
:authors: Evgeny Momotov (KrymmyEM)
:license: MIT License
Copyright: (c) 2024 Evgeny
"""

from .enums import *
from .classes import *
from .exceptions import *
from .tg_stat import TGStatSync

__author__ = "KrymmyEM"
__version__ = "0.1.8"